@@ -361,9 +361,7 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	KHelpMenu* help = new KHelpMenu(this, KGlobal::mainComponent().aboutData());
 	menuBar()->addMenu(help->menu());
 
-#ifdef __GNUC__
 #warning TODO: Port to PlotsModel
-#endif
 // 	connect(b_funcsModel, SIGNAL(functionModified(QString,Analitza::Expression)),
 // 			c_results, SLOT(modifyVariable(QString,Analitza::Expression)));
 // 	connect(b_funcsModel, SIGNAL(functionRemoved(QString)),
@@ -596,7 +594,7 @@ void KAlgebra::save3DGraph()
 
 void KAlgebra::toggleSquares()
 {
-	m_graph2d->setSquares(!m_graph2d->squares());
+	m_graph2d->setShowGrid(!m_graph2d->showGrid());
 }
 
 void KAlgebra::toggleKeepAspect()
@@ -719,8 +717,9 @@ void KAlgebra::add3D(const Analitza::Expression& exp)
 {
 #ifdef HAVE_OPENGL
 	t_model3d->clear();
-	t_model3d->addPlot(Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D, c_results->analitza()->variables())
-													 .create(Qt::yellow, "func3d_console"));
+	Analitza::PlotBuilder plot = Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D, c_results->analitza()->variables());
+	Q_ASSERT(plot.canDraw());
+	t_model3d->addPlot(plot.create(Qt::yellow, "func3d_console"));
 	m_tabs->setCurrentIndex(2);
 #endif
 }
